--
-- BSnd
-- Description: Simple addon to enable/disable sounds, and adjust the volume via commands.
-- Author: Tom Bell
--

--
-- A global table to store functions for different command arguments.
--
local actions

--
-- BSND_Load
--  Initialises the function table for the different command arguments, and registers the slash commands.
--
function BSND_Load()
	actions = {
		["sfx"] = BSND_ToggleSoundEffect,
		["errorspeech"] = BSND_ToggleErrorSpeech,
		["emotesounds"] = BSND_ToggleEmoteSounds,
		["petsounds"] = BSND_TogglePetSounds,
		["music"] = BSND_ToggleMusic,
		["ambience"] = BSND_ToggleAmbience,
		["master_volume"] = BSND_SetMasterVolume,
		["sfx_volume"] = BSND_SetSoundEffectsVolume,
		["music_volume"] = BSND_SetMusicVolume,
		["ambience_volume"] = BSND_SetAmbienceVolume,
	}

	SlashCmdList["BSND_SLASH_CMD"] = BSND_SlashCommandHandler
	SLASH_BSND_SLASH_CMD1 = "/bsnd"
	SLASH_BSND_SLASH_CMD2 = "/snd"

	DEFAULT_CHAT_FRAME:AddMessage("BSnd loaded successfully")
end

--
-- BSND_SlashCommandHandler
--  Split the argument to the slash command, then call the correct function for that argument.
--
function BSND_SlashCommandHandler(args)
	local variable, argument = strsplit(" ", args, 2)
	actions[variable](argument)
end

--
-- BSND_ToggleSoundEffect
--  Sets the C variable for Sound_EnableSFX to 0 or 1.
--
function BSND_ToggleSoundEffect(toggle)
	if toggle == "enable" then
			SetCVar("Sound_EnableSFX", 1)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: sound effects |cFFFFFFFFenabled")
	elseif toggle == "disable" then
			SetCVar("Sound_EnableSFX", 0)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: sound effects |cFFFFFFFFdisabled")
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: incorrect argument specified - '|cFFFFFFFF" .. toggle .. "|cFF8888CC'")
	end
end

--
-- BSND_ToggleErrorSpeech
-- Sets the C variable for Sound_EnableErrorSpeech to 0 or 1.
--
function BSND_ToggleErrorSpeech(toggle)
	if toggle == "enable" then
			SetCVar("Sound_EnableErrorSpeech", 1)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: error speech |cFFFFFFFFenabled")
	elseif toggle == "disable" then
			SetCVar("Sound_EnableErrorSpeech", 0)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: error speech |cFFFFFFFFdisabled")
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: incorrect argument specified - '|cFFFFFFFF" .. toggle .. "|cFF8888CC'")
	end
end

--
-- BSND_ToggleEmoteSounds
-- Sets the C variable for Sound_EnableEmoteSounds to 0 or 1.
--
function BSND_ToggleEmoteSounds(toggle)
	if toggle == "enable" then
			SetCVar("Sound_EnableEmoteSounds", 1)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: emote sounds |cFFFFFFFFenabled")
	elseif toggle == "disable" then
			SetCVar("Sound_EnableEmoteSounds", 0)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: emote sounds |cFFFFFFFFdisabled")
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: incorrect argument specified - '|cFFFFFFFF" .. toggle .. "|cFF8888CC'")
	end
end

--
-- BSND_TogglePetSounds
-- Sets the C variable for Sound_EnablePetSounds to 0 or 1.
--
function BSND_TogglePetSounds(toggle)
	if toggle == "enable" then
			SetCVar("Sound_EnablePetSounds", 1)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: pet sounds |cFFFFFFFFenabled")
	elseif toggle == "disable" then
			SetCVar("Sound_EnablePetSounds", 0)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: pet sounds |cFFFFFFFFdisabled")
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: incorrect argument specified - '|cFFFFFFFF" .. toggle .. "|cFF8888CC'")
	end
end

--
-- BSND_ToggleMusic
-- Sets the C variable for Sound_EnableMusic to 0 or 1.
--
function BSND_ToggleMusic(toggle)
	if toggle == "enable" then
			SetCVar("Sound_EnableMusic", 1)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: music |cFFFFFFFFenabled")
	elseif toggle == "disable" then
			SetCVar("Sound_EnableMusic", 0)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: music |cFFFFFFFFdisabled")
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: incorrect argument specified - '|cFFFFFFFF" .. toggle .. "|cFF8888CC'")
	end
end

--
-- BSND_ToggleAmbience
-- Sets the C variable for Sound_EnableAmbience to 0 or 1.
--
function BSND_ToggleAmbience(toggle)
	if toggle == "enable" then
			SetCVar("Sound_EnableAmbience", 1)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: ambience |cFFFFFFFFenabled")
	elseif toggle == "disable" then
			SetCVar("Sound_EnableAmbience", 0)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: ambience |cFFFFFFFFdisabled")
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: incorrect argument specified - '|cFFFFFFFF" .. toggle .. "|cFF8888CC'")
	end
end

--
-- BSND_SetMasterVolume
-- Sets the C variable for Sound_MasterVolume to a value between 0 and 1.
--
function BSND_SetMasterVolume(volume)
	if tonumber(volume) <= 100 then
		if tonumber(volume) >= 0 then
			SetCVar("Sound_MasterVolume", volume / 100)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: master volume set to |cFFFFFFFF" .. volume .. "|cFF8888CC%")
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: invalid volume level, volume must be between 0 and 100")
	end
end

--
-- BSND_SetSoundEffectsVolume
-- Sets the C variable for Sound_SFXVolume to a value between 0 and 1.
--
function BSND_SetSoundEffectsVolume(volume)
	if tonumber(volume) <= 100 then
		if tonumber(volume) >= 0 then
			SetCVar("Sound_SFXVolume", volume / 100)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: sound effects volume set to |cFFFFFFFF" .. volume .. "|cFF8888CC%")
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: invalid volume level, volume must be between 0 and 100")
	end
end

--
-- BSND_SetMusicVolume
-- Sets the C variable for Sound_MusicVolume to a value between 0 and 1.
--
function BSND_SetMusicVolume(volume)
	if tonumber(volume) <= 100 then
		if tonumber(volume) >= 0 then
			SetCVar("Sound_MusicVolume", volume / 100)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: music volume set to |cFFFFFFFF" .. volume .. "|cFF8888CC%")
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: invalid volume level, volume must be between 0 and 100")
	end
end

--
-- BSND_SetAmbienceVolume
-- Sets the C variable for Sound_AmbienceVolume to a value between 0 and 1.
--
function BSND_SetAmbienceVolume(volume)
	if tonumber(volume) <= 100 then
		if tonumber(volume) >= 0 then
			SetCVar("Sound_AmbienceVolume", volume / 100)
			DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: ambience volume set to |cFFFFFFFF" .. volume .. "|cFF8888CC%")
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("|cFF8888CCBSnd: invalid volume level, volume must be between 0 and 100")
	end
end

--
-- Call BSND_Load to initialise the addon.
--
BSND_Load()
